/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: Csv.java 3290 2007-05-31 15:30:51Z gdecarnin $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.engine.csv;

import org.objectweb.petals.common.descriptor.Extensions;
import org.objectweb.petals.component.common.HandlingException;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * This component transforms a CSV document in an XML document. It uses the
 * JavaCSV library to do this transformation. NB. To transform the XML output,
 * use another XSLT service engine SU.
 * 
 * @version $Rev: $ $Date: $
 * @author Marc Dutoo - Open Wide
 * @author Guillaume Decarnin - Open Wide
 */
public interface Csv {
    
    /**
     * Transforms the given CSV content input in XML and returns it
     * @param csv
     * @param extensions used to configure CSV parsing
     * @throws HandlingException
     */
    public Document transformCsvToXml(String csv, Extensions extensions) throws HandlingException;
    
    /**
     * Transforms the given XML tabular data to CSV.
     * There is no requirement on the format (tags...) besides the fact that
     * they have to be a two level tree.
     * @param xml the XML tabular data to be written as CSV
     * @param extensions the service extensions
     * @return CSV String
     * @throws HandlingException if conversion error
     */
    public String transformXmlToCsv(Node xml, Extensions extensions) throws HandlingException;
}
